/*
 * Copyright (c) 2021, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <msp430.h>
#include <stdbool.h>
#include "tps272c45evm.h"

/**
 * tps272c45_basic_setup.c
 */

int main(void)
{
    /* Stop/Hold the Watchdog */
    WDTCTL = WDTPW | WDTHOLD;

    /* Configuring all digital signals */
    DIA_EN_OUT &= ~DIA_EN_PIN;
    DIA_EN_DIR |= DIA_EN_PIN;
    SEL_OUT &= ~SEL_PIN;
    SEL_DIR |= SEL_PIN;
    EN1_OUT &= ~EN1_PIN;
    EN1_DIR |= EN1_PIN;
    EN2_OUT &= ~EN2_PIN;
    EN2_DIR |= EN2_PIN;

    /* Configuring Push Buttons */
    /* S2 */
    P2REN |= BIT1;
    P2OUT |= BIT1;
    P2IES |= BIT1;
    P2IFG &= ~BIT1;
    P2IE |= BIT1;

    /* S1 */
    P1REN |= BIT1;
    P1OUT |= BIT1;
    P1IES |= BIT1;
    P1IFG &= ~BIT1;
    P1IE |= BIT1;

    /* Configuring LEDs */
    P1OUT |= BIT0;
    P1DIR |= BIT0;
    P4OUT &= ~BIT7;
    P4DIR |= BIT7;

    /* Configuring Current Limit Pins (Default ILIM1) */
    ILIM1_OUT |= (ILIM1_PIN);
    ILIM1_DIR |= (ILIM1_PIN);
    ILIM2_OUT &= ~(ILIM2_PIN);
    ILIM2_DIR |= (ILIM2_PIN);

    /* Enabling interrupts and sleeping */
    __bis_SR_register(LPM0_bits + GIE);
}

#pragma vector=PORT1_VECTOR
__interrupt void Port_1(void)
{
    switch (__even_in_range(P1IV, 16))
    {
        case P1IV_NONE:
            break;   // Vector  0: no interrupt
        case P1IV_P1IFG0:
            break;   // Vector  2: P1.0
        case P1IV_P1IFG1:
            ILIM1_OUT ^= ILIM1_PIN;
            ILIM2_OUT ^= ILIM2_PIN;
            P1OUT ^= BIT0;
            P4OUT ^= BIT7;
            break;
        case P1IV_P1IFG2:
            break;   // Vector  6: P1.2
        case P1IV_P1IFG3:
            break;   // Vector  8: P1.3
        case P1IV_P1IFG4:
            break;
        case P1IV_P1IFG5:
            break;   // Vector 12: P1.5
        case P1IV_P1IFG6:
            break;   // Vector 14: P1.6
        case P1IV_P1IFG7:
            break;   // Vector 16: P1.7
        default:
            break;
    }
}

#pragma vector=PORT2_VECTOR
__interrupt void Port_2(void)
{
    switch (__even_in_range(P2IV, 16))
    {
        case P2IV_NONE:
            break;   // Vector  0: no interrupt
        case P2IV_P2IFG0:
            break;   // Vector  2: P2.0
        case P2IV_P2IFG1:
            EN1_OUT ^= EN1_PIN;
            break;
        case P2IV_P2IFG2:
            break;   // Vector  6: P2.2
        case P2IV_P2IFG3:
            break;   // Vector  8: P2.3
        case P2IV_P2IFG4:
            break;   // Vector 10: P2.4
        case P2IV_P2IFG5:
            break;   // Vector 12: P2.5
        case P2IV_P2IFG6:
            break;   // Vector 14: P2.6
        case P2IV_P2IFG7:
            break;   // Vector 16: P2.7
        default:
            break;
    }
}

